; ----------------------------------------------------
; PortableArmagetron
; ----------------------------------------------------
; Author: sarkos & Joshua
; Utilisant comme base de travail le script de John T. Haller
; License: GPL
; Ce script permet de crer PortableArmagetron.
; Compiler: NSIS (http://nsis.sourceforge.net).
; Requires plugin: ipicsplash, FindProcessDLL
; Depends: PortableArmagetronlang_fr.nsh, FramakeyFunctions.nsh
; $id=PortableArmagetron.nsi $date=2006-06-11
; ----------------------------------------------------
; Copyright (C) 2004-2006 John T. Haller
; Copyright (C) 2005-2006 Framakey Team

; Website: http://www.framakey.org

; This program is free software; you can redistribute it and/or
; modify it under the terms of the GNU General Public License
; as published by the Free Software Foundation; either version 2
; of the License, or (at your option) any later version.

; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
; GNU General Public License for more details.

; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
; ----------------------------------------------------
; Gnral

; Dfinition variables chemins
!define DEFAULTEXE "armagetronad.exe" ;Nom de l'excutable par dfaut
!define DEFAULTAPPDIR "Armagetron Advanced" ;Rpertoire par dfaut de l'application
!define DEFAULTUSERPROFILE "Profile" ;Rpertoire utilisateur par dfaut

; Dfinition variables entte
!define NAME "PortableArmagetron" ;Nom du lanceur (forme abrge)
!define FULLNAME "Portable Armagetron" ;Nom complet du lanceur
!define APP "Armagetron" ;Nom de l'application
!define VER "1.0.0.5" ;Version du lanceur
!define PROJECT "Framakey" ;Nom du projet
!define COMPANY "Framakey.org" ;Nom du groupe dveloppant le projet
!define DEVELOP "sarkos, joshua" ;Noms des dveloppeurs
!define WEBSITE "http://www.framakey.org" ;Site Internet

; ----------------------------------------------------
; Langues

  LoadLanguageFile "${NSISDIR}\Contrib\Language Files\French.nlf"

; ----------------------------------------------------
; Inclusion du fichier de lang du lanceur

  !include "PortableArmagetronLang_fr.nsh"

; ----------------------------------------------------
; Inclusion du fichier de fonctions et macros

  !include "FramakeyFunctions-0605.nsh"

; ----------------------------------------------------
; Informations de compilation

; Nom de l'excutable
  Name "${NAME}"
; Etiquette
  Caption "${CAPTIONTEXT}"
; Icone
  Icon "${NAME}.ico"
  WindowIcon Off
; Nom du fichier  crer
  OutFile "${NAME}.exe"

; Runtime Switches
  SetDateSave on
  SetDatablockOptimize on
  CRCCheck On
  SilentInstall Silent
  AutoCloseWindow True

; ----------------------------------------------------
; Version Informations

  VIProductVersion "${VER}"
  VIAddVersionKey FileDescription "${FILEDESCRIPTIONTEXT}"
  VIAddVersionKey LegalTrademarks "${LEGALTRADEMARKSTEXT}"
  VIAddVersionKey LegalCopyright "${LEGALCOPYRIGHTTEXT}"
  VIAddVersionKey Comments "${COMMENTSTEXT}"
  VIAddVersionKey CompanyName "${COMPANY}"
  VIAddVersionKey OriginalFilename "${NAME}.exe"
  VIAddVersionKey FileVersion "${VER}"

; ----------------------------------------------------
; Variables

  Var IniPath
  Var AppDirectory
  Var AppExecutable
  Var UserProfileDir
  Var AdditionalParameters
  Var DisableSplashScreen
  Var ExecString

; ----------------------------------------------------
; Sections

Section "Main"

; Trouver le fichier INI, s'il y en a un
  IfFileExists "$EXEDIR\${NAME}.ini" "" CheckDataINI
    StrCpy "$IniPath" "$EXEDIR"
    Goto ReadINI

  CheckDataINI:
    IfFileExists "$EXEDIR\..\..\Data\AppsData\${NAME}\${NAME}.ini" "" NoINI
    StrCpy "$INIPATH" "$EXEDIR\..\..\Data\${NAME}\"
      Goto ReadINI

  ReadINI:
; Lit les paramtres du fichier INI
    ReadINIStr $0 "$IniPath\${NAME}.ini" "${NAME}" "${APP}Directory"
      StrCpy "$AppDirectory" "$EXEDIR\$0"

; Vrifie que les paramtres requis ci-dessus sont prsents
    IfErrors NoINI

    ReadINIStr $0 "$IniPath\${NAME}.ini" "${NAME}" "AdditionalParameters"
      StrCpy "$AdditionalParameters" $0
    ReadINIStr $0 "$IniPath\${NAME}.ini" "${NAME}" "${APP}Executable"
      StrCpy "$AppExecutable" $0
    ReadINIStr $0 "$IniPath\${NAME}.ini" "${NAME}" "${APP}Profile"
      StrCpy "$UserProfileDir" $0
    ReadINIStr $0 "$IniPath\${NAME}.ini" "SplashScreen" "DisableSplashScreen"
      StrCpy "$DisableSplashScreen" $0

; Pour n'importe quelle paramtre du fichier INI non requis contenant une chaine vide, ignorer les erreurs associes
    ClearErrors

; Correct PROGRAMEXECUTABLE si paramtre vide
    StrCmp $AppExecutable "" "" EndINI
    StrCpy "$AppExecutable" "${DEFAULTEXE}"
    Goto EndINI

  NoINI:
; Pas de fichier INI, nous utiliserons les paramtres par dfaut
    StrCpy "$AdditionalParameters" ""
    StrCpy "$AppExecutable" "${DEFAULTEXE}"
    StrCpy "$UserProfileDir" "${DEFAULTUSERPROFILE}"
    StrCpy "$DisableSplashScreen" "false"

    IfFileExists "$EXEDIR\${DEFAULTAPPDIR}\${DEFAULTEXE}" "" NoProgramEXE
      StrCpy "$AppDirectory" "$EXEDIR\${DEFAULTAPPDIR}"

  EndINI:
    IfFileExists "$AppDirectory\$AppExecutable" FoundProgramEXE

  NoProgramEXE:
; Si le chemin pointant vers l'excutable est invalide
    MessageBox MB_OK|MB_ICONEXCLAMATION `${NOEXEMSG}`
    Abort

  FoundProgramEXE:
    !insertmacro FindProcess $AppExecutable
    StrCmp $DisableSplashScreen "true" GetAppParameters
; Affiche le splash screen
    InitPluginsDir
    !insertmacro SplashInit "ipicsplash" "${NAME}_splash.jpg" ""

; Check des paramtres
  GetAppParameters:
    Call GetParameters
    Pop $0

; Routine si pas de paramtres
  StrCmp "'$0'" "''" "" ExecWithParameters
  StrCpy $ExecString `"$AppDirectory\$AppExecutable"`
  Goto AdditionalParameters

; Routine si paramtres
  ExecWithParameters:
    StrCpy $ExecString `"$AppDirectory\$AppExecutable" $0`
    Goto ExecApp

  AdditionalParameters:
    StrCmp $AdditionalParameters "" ProfileEnvironment

; Additional Parameters
    StrCpy $ExecString `$ExecString $AdditionalParameters`

; Fake home directory
  ProfileEnvironment:
; Set the %USERPROFILE% directory if we have a path
    StrCmp $UserProfileDir "" NoProfile
    IfFileExists "$EXEDIR\$UserProfileDir\*.*" "" NoProfile
      System::Call 'Kernel32::SetEnvironmentVariableA(t, t) i("USERPROFILE", "$EXEDIR\$UserProfileDir").r0'
      Goto ExecApp

; Si profil introuvable
  NoProfile:
    MessageBox MB_OK|MB_ICONEXCLAMATION `${NOPROFILEMSG}`
    Abort

; Lancement application
  ExecApp:
    Exec "$ExecString"

SectionEnd

Section .onInit
  Call Mutex
SectionEnd

; -------------------------------------------
; Fin du script